//Replication File for Barnes & Beaulieu CPS
//Created: January 18, 2018
//This file contains the code necessary to replicate the Tables 1 & 2,  Figures 1-4, Appendix Tables A1 & A2


//Bring in Data
//clear
//use "Barnes&Beaulieu_CPS_Replication.dta"

set more off 

//Table 1: Explaining Corruption Perceptions: Multinomial Logit 
 mlogit  opportunity fem_honest  male_outsider fem_outsider  male_risk  fem_risk female education age income fulltime parttime student, base(3)
  
//Table 2: Explaining Corruption Perceptions By Respondent Sex: Multinomial Logit 
 mlogit  opportunity fem_honest  male_outsider fem_outsider  male_risk  fem_risk female  fh_sex mo_sex fo_sex  mr_sex fr_sex  education age income fulltime parttime student, base(3)
  

//Figure 1: Distribution of Fraud Perseptions By Experimental Treatment 
//Note: Figure 1 was created in excel using this data
tab opportunity male_outsider 
tab opportunity male_honest
tab opportunity male_risk

tab opportunity fem_outsider
tab opportunity fem_honest
tab opportunity fem_risk


//Figure 2:Predicted Probability of Responding Very Likely By Experimental Treatment  
//Note: This figure is created using Clarify. User must install clarify to run this command. 
set more off 
capture drop b*
estsimp mlogit  opportunity fem_honest  male_outsider fem_outsider  male_risk  fem_risk  female education age income fulltime parttime student 


capture drop closeL closeH close closex closeL8 closeH8
capture drop circle 


	set type double 
	generate closeL=.
	generate closeH=.
	generate close=.
	generate closex=.
	generate closeL8=.
	generate closeH8=.

	setx mean
	setx female 1
	setx fulltime 1
	setx parttime 0
	setx student 0

	setx fem_honest 0
	setx fem_risk 0
	setx male_risk 0
	setx fem_outsider 0
	setx male_outsider 0
	

********************
//Honest Male//
********************
# delimit ;	
	local a = 1;  
	local b = 1; 

# delimit ;
set more off;	
	while `a' <= 1 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr

	setx fem_honest 1
	setx fem_risk 0
	setx male_risk 0
	setx fem_outsider 0
	setx male_outsider 0
	

********************
//Honest Female//
********************
# delimit ;
set more off;	
	while `a' <= 2 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;
	replace close = r(mean) in `b';
	drop pi;
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr

 
setx fem_honest 0
	setx fem_risk 0
	setx male_risk 0
	setx fem_outsider 0
	setx male_outsider 1
	

********************
//Marginalized Male//
********************
# delimit ;
set more off;	
	while `a' <= 3 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;		
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr 	
	 
	

setx fem_honest 0
	setx fem_risk 0
	setx male_risk 0
	setx fem_outsider 1
	setx male_outsider 0
	

********************
//Marginalized Female//
********************
# delimit ;
set more off;	
	while `a' <= 4 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
		_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr 
 
	setx fem_honest 0
	setx fem_risk 0
	setx male_risk 1
	setx fem_outsider 0
	setx male_outsider 0
	

********************
//Risk Male//
********************
# delimit ;
set more off;	
	while `a' <= 5 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;			
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr 
	
	setx fem_honest 0
	setx fem_risk 1
	setx male_risk 0
	setx fem_outsider 0
	setx male_outsider 0
	

********************
//Risk Female//
********************
# delimit ;
set more off;	
	while `a' <= 6 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;		
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr 	
	
	 	
		
gen circle = 1 if closex==2	
replace circle = 1 if closex==4		
replace circle = 1 if closex==6
replace circle = 0 if closex==1	
replace circle = 0 if closex==3		
replace circle = 0 if closex==5
 			
 # delimit ;
twoway rbar closeL closeH closex  if circle==0, color(black) barwidth (.0010)||
rbar closeL8 closeH8 closex  if circle==0, color(black) barwidth (.050)||
 scatter close closex if circle==0, symbol(square) color(black) msize(vlarge) ||
 rbar closeL closeH closex if circle==1 , color(black) barwidth (.0010)||
  rbar closeL8 closeH8 closex if circle==1 , color(gray) barwidth (.050)||

 scatter close closex if circle==1, msize(vlarge) color(gray) ,
   			legend(order(- 6 "Female Representative" - 3 "Male Representative")
  			row(1) col(2)  symx(tiny) lwidth(0) size(small) colgap(vsmall) region(lwidth(none)))
  			xtitle(" ", size(medium))
  			ytitle("Pr(Very Likely)", size(small))
  			title("All Respondents", size(medium) color(black))
			xlab(1 "Honest Male" 2 "Honest Female" 3 "Outsider Male" 4 "Outsider Female" 5 "Risk Averse Male" 6 "Risk Averse Female", angle(45))
			
            graphregion(fcolor(white))
 			plotregion(fcolor(white))
 			graphregion(color(white))
 			name(mlogit, replace);
 #delimit cr 	


			
			
//Figure 3: Distribution of Fraud Perseptions By Respondent Sex and Experimental Treatment  
//Note: Figure 3 was created in excel using this data
tab opportunity male_outsider if female==0
tab opportunity male_outsider if female==1
 
tab opportunity male_honest if female==0
tab opportunity male_honest if female==1

tab opportunity male_risk if female==0
tab opportunity male_risk if female==1


tab opportunity fem_outsider if female==0
tab opportunity fem_outsider if female==1

tab opportunity fem_honest if female==0
tab opportunity fem_honest if female==1

tab opportunity fem_risk if female==0
tab opportunity fem_risk if female==1


//Figure 4:Predicted Probability of Responding Very Likely By Respondent Sex and Experimental Treatment  
//Note: This figure is created using Clarify. User must install clarify to run this command. 

//Top Panel: Male Respondents


set more off 
capture drop b*
estsimp mlogit  opportunity fem_honest  male_outsider fem_outsider  male_risk  fem_risk female  fh_sex  mo_sex fo_sex  mr_sex fr_sex  education age income fulltime parttime student, base(3)

capture drop closeL closeH close closex closeL8 closeH8
capture drop circle 

	set type double 
	generate closeL=.
	generate closeH=.
	generate close=.
	generate closex=.
	generate closeL8=.
	generate closeH8=.

	setx mean
	setx female 0
	setx fulltime 1
	setx parttime 0
	setx student 0

	setx fem_honest 0
	setx fem_risk 0
	setx male_risk 0
	setx fem_outsider 0
	setx male_outsider 0
	
	setx fh_sex 0
	//setx mh_sex 0  //omitted from analysis
	setx mo_sex 0
	setx fo_sex  0
	setx mr_sex 0
	setx fr_sex 0
	

********************
//Honest Male//
********************
# delimit ;	
	local a = 1;  
	local b = 1; 

# delimit ;
set more off;	
	while `a' <= 1 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr

	setx fem_honest 1
	setx fem_risk 0
	setx male_risk 0
	setx fem_outsider 0
	setx male_outsider 0
	

********************
//Honest Female//
********************
# delimit ;
set more off;	
	while `a' <= 2 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;
	replace close = r(mean) in `b';
	drop pi;
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr

 
setx fem_honest 0
	setx fem_risk 0
	setx male_risk 0
	setx fem_outsider 0
	setx male_outsider 1
	

********************
//Outside Male//
********************
# delimit ;
set more off;	
	while `a' <= 3 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;		
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr 	
	 
	

setx fem_honest 0
	setx fem_risk 0
	setx male_risk 0
	setx fem_outsider 1
	setx male_outsider 0
	

********************
//Outside Female//
********************
# delimit ;
set more off;	
	while `a' <= 4 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
		_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr 
 
	setx fem_honest 0
	setx fem_risk 0
	setx male_risk 1
	setx fem_outsider 0
	setx male_outsider 0
	

********************
//Risk Male//
********************
# delimit ;
set more off;	
	while `a' <= 5 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;			
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr 
	
	setx fem_honest 0
	setx fem_risk 1
	setx male_risk 0
	setx fem_outsider 0
	setx male_outsider 0
	

********************
//Risk Female//
********************
# delimit ;
set more off;	
	while `a' <= 6 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;		
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr 	
	
	 	
		
gen circle = 1 if closex==2	
replace circle = 1 if closex==4		
replace circle = 1 if closex==6
replace circle = 0 if closex==1	
replace circle = 0 if closex==3		
replace circle = 0 if closex==5
			
 # delimit ;
twoway rbar closeL closeH closex  if circle==0, color(black) barwidth (.0010)||
rbar closeL8 closeH8 closex  if circle==0, color(gray) barwidth (.050)||
 scatter close closex if circle==0 & closex==1, symbol(square) color(black) msize(vlarge) ||
 scatter close closex if circle==0 & closex==3, symbol(square) color(black) msize(vlarge) ||
 scatter close closex if circle==0 & closex==5, symbol(square) color(black) msize(vlarge) ||

  
 rbar closeL closeH closex if circle==1 , color(black) barwidth (.0010)||
  rbar closeL8 closeH8 closex if circle==1 , color(gray) barwidth (.050)||
 scatter close closex if circle==1, msize(vlarge) color(gray) ||
 scatter close closex if circle==1, msize(vlarge) color(gray) ||
 scatter close closex if circle==1, msize(vlarge) color(gray) ,
   			legend(order(- 8 "Female Representative" - 3 "Male Representative")
  			row(1) col(2)  symx(tiny) lwidth(0) size(small) colgap(vsmall) region(lwidth(none)))
  			xtitle("Treatment", size(medium))
  			ytitle("Pr(Very Likely)", size(small))
  			title("Male Respondents", size(medium) color(black))
			xlab(1 "Honest Male" 2 "Honest Female" 3 "Outsider Male" 4 "Outsider Female" 5 "Riskk Adverse Male" 6 "Risk Adverse Female", angle(45))
            graphregion(fcolor(white))
 			plotregion(fcolor(white))
 			graphregion(color(white))
 			name(mlogit, replace);
 #delimit cr 	


//Bottom Panel: Female Respondents

set more off 
capture drop b*
estsimp mlogit  opportunity fem_honest  male_outsider fem_outsider  male_risk  fem_risk female  fh_sex  mo_sex fo_sex  mr_sex fr_sex  education age income fulltime parttime student, base(3)

capture drop closeL closeH close closex closeL8 closeH8
capture drop circle 


	set type double 
	generate closeL=.
	generate closeH=.
	generate close=.
	generate closex=.
	generate closeL8=.
	generate closeH8=.

	setx mean
	setx female 1
	setx fulltime 1
	setx parttime 0
	setx student 0

	setx fem_honest 0
	setx fem_risk 0
	setx male_risk 0
	setx fem_outsider 0
	setx male_outsider 0
	
	setx fh_sex 0
	//setx mh_sex 0  //omitted from analysis
	setx mo_sex 0
	setx fo_sex  0
	setx mr_sex 0
	setx fr_sex 0
	

********************
//Honest Male//
********************
# delimit ;	
	local a = 1;  
	local b = 1; 

# delimit ;
set more off;	
	while `a' <= 1 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr

	setx fem_honest 1
	setx fem_risk 0
	setx male_risk 0
	setx fem_outsider 0
	setx male_outsider 0
	
	setx fh_sex 1
	//setx mh_sex 0  //omitted from analysis
	setx mo_sex 0
	setx fo_sex  0
	setx mr_sex 0
	setx fr_sex 0
	

********************
//Honest Female//
********************
# delimit ;
set more off;	
	while `a' <= 2 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;
	replace close = r(mean) in `b';
	drop pi;
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr

 
setx fem_honest 0
	setx fem_risk 0
	setx male_risk 0
	setx fem_outsider 0
	setx male_outsider 1
	

	setx fh_sex 0
	//setx mh_sex 0  //omitted from analysis
	setx mo_sex 1
	setx fo_sex  0
	setx mr_sex 0
	setx fr_sex 0
	
	
********************
//Outside Male//
********************
# delimit ;
set more off;	
	while `a' <= 3 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;		
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr 	
	 
	

setx fem_honest 0
	setx fem_risk 0
	setx male_risk 0
	setx fem_outsider 1
	setx male_outsider 0

	setx fh_sex 0
	//setx mh_sex 0  //omitted from analysis
	setx mo_sex 0
	setx fo_sex  1
	setx mr_sex 0
	setx fr_sex 0
	

********************
//Outside Female//
********************
# delimit ;
set more off;	
	while `a' <= 4 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
		_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr 
 
	setx fem_honest 0
	setx fem_risk 0
	setx male_risk 1
	setx fem_outsider 0
	setx male_outsider 0
	
	setx fh_sex 0
	//setx mh_sex 0  //omitted from analysis
	setx mo_sex 0
	setx fo_sex  0
	setx mr_sex 1
	setx fr_sex 0
	

********************
//Risk Male//
********************
# delimit ;
set more off;	
	while `a' <= 5 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;			
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr 
	
	setx fem_honest 0
	setx fem_risk 1
	setx male_risk 0
	setx fem_outsider 0
	setx male_outsider 0
	
	setx fh_sex 0
	//setx mh_sex 0  //omitted from analysis
	setx mo_sex 0
	setx fo_sex  0
	setx mr_sex 0
	setx fr_sex 1
	

********************
//Risk Female//
********************
# delimit ;
set more off;	
	while `a' <= 6 {;
	replace closex =`a' in `b'; 	
	quietly simqi, prval(4) genpr (pi);	
	_pctile pi, p(2.5 , 97.5);   
	    
	replace closeL = r(r1) in `b';	
	replace closeH = r(r2) in `b';
	_pctile pi, p(8 , 92); 
	replace closeL8 = r(r1) in `b';
	replace closeH8 = r(r2) in `b';

	summarize pi;		
	replace close = r(mean) in `b';
	drop pi;	
	local a = `a' + 1;		
	local b = `b' + 1;			
	};	
 #delimit cr 	
	
	 	
		
gen circle = 1 if closex==2	
replace circle = 1 if closex==4		
replace circle = 1 if closex==6
replace circle = 0 if closex==1	
replace circle = 0 if closex==3		
replace circle = 0 if closex==5
			
 # delimit ;
twoway rbar closeL closeH closex  if circle==0, color(black) barwidth (.0010)||
rbar closeL8 closeH8 closex  if circle==0, color(black) barwidth (.050)||
 scatter close closex if circle==0, symbol(square) color(black) msize(vlarge) ||
 rbar closeL closeH closex if circle==1 , color(gray) barwidth (.0010)||
  rbar closeL8 closeH8 closex if circle==1 , color(gray) barwidth (.050)||

 scatter close closex if circle==1, msize(vlarge) color(gray) ,
   			legend(order(- 6 "Female Representative" - 3 "Male Representative")
  			row(1) col(2)  symx(tiny) lwidth(0) size(small) colgap(vsmall) region(lwidth(none)))
  			xtitle("Treatment", size(medium))
  			ytitle("Pr(Very Likely)", size(small))
  			title("Female Respondents", size(medium) color(black))
			xlab(1 "Honest Male" 2 "Honest Female" 3 "Outsider Male" 4 "Outsider Female" 5 "Risk Averse Male" 6 "Risk Averse Female", angle(45))
            graphregion(fcolor(white))
 			plotregion(fcolor(white))
 			graphregion(color(white))
 			name(mlogit, replace);
 #delimit cr 	

 
//Appendix Tables

//Table A1: Mean Sample Characteristics, by Treatment Category  


//Honest Female Column (1) 
sum female if fem_honest ==1
sum education if fem_honest ==1
sum age if fem_honest ==1
sum income if fem_honest ==1
sum fulltime if fem_honest ==1
sum parttime if fem_honest ==1
sum student if fem_honest ==1

//Honest Male Column (2) 
sum female if male_honest ==1
sum education if male_honest ==1
sum age if male_honest ==1
sum income if male_honest ==1
sum fulltime if male_honest ==1
sum parttime if male_honest ==1
sum student if male_honest ==1

//Risk Averse Female Column (3) 
sum female if fem_risk ==1
sum education if fem_risk ==1
sum age if fem_risk ==1
sum income if fem_risk ==1
sum fulltime if fem_risk ==1
sum parttime if fem_risk ==1
sum student if fem_risk ==1

//Risk Averse Male Column (4) 
sum female if male_risk ==1
sum education if male_risk ==1
sum age if male_risk ==1
sum income if male_risk ==1
sum fulltime if male_risk ==1
sum parttime if male_risk ==1
sum student if male_risk ==1

//Marginalized Female Column (5) 
sum female if fem_outsider ==1
sum education if fem_outsider ==1
sum age if fem_outsider ==1
sum income if fem_outsider ==1
sum fulltime if fem_outsider ==1
sum parttime if fem_outsider ==1
sum student if fem_outsider ==1

//Marginalized Male Column (6) 
sum female if male_outsider ==1
sum education if male_outsider ==1
sum age if male_outsider ==1
sum income if male_outsider ==1
sum fulltime if male_outsider ==1
sum parttime if male_outsider ==1
sum student if male_outsider ==1



//Table A2: Predict Treatment Categories

 mlogit opp_treat education age income fulltime parttime student, base(0)
 
